'use strict';

// const printAST = require('ast-pretty-print')
var _require = require('babel-macros'),
    createMacro = _require.createMacro;

var replace = require('./replace');

module.exports = createMacro(codegenMacros);

function codegenMacros(_ref) {
  var references = _ref.references,
      state = _ref.state;

  references.default.forEach(function (referencePath) {
    if (referencePath.parentPath.type === 'TaggedTemplateExpression') {
      asTag(referencePath.parentPath.get('quasi'), state);
    } else if (referencePath.parentPath.type === 'CallExpression') {
      asFunction(referencePath.parentPath.get('arguments'), state);
    } else if (referencePath.parentPath.type === 'JSXOpeningElement') {
      asJSX({
        attributes: referencePath.parentPath.get('attributes'),
        children: referencePath.parentPath.parentPath.get('children')
      }, state);
    } else {
      // TODO: throw a helpful error message
    }
  });
}

function asTag(quasiPath, _ref2) {
  var filename = _ref2.file.opts.filename;

  var string = quasiPath.parentPath.get('quasi').evaluate().value;
  replace({
    path: quasiPath.parentPath,
    string,
    filename
  });
}

function asFunction(argumentsPaths, _ref3) {
  var filename = _ref3.file.opts.filename;

  var string = argumentsPaths[0].evaluate().value;
  replace({
    path: argumentsPaths[0].parentPath,
    string,
    filename
  });
}

// eslint-disable-next-line no-unused-vars
function asJSX(_ref4, _ref5) {
  var attributes = _ref4.attributes,
      children = _ref4.children;
  var filename = _ref5.file.opts.filename;

  var string = children[0].node.expression.value;
  if (children[0].node.expression.type === 'TemplateLiteral') {
    string = children[0].get('expression').evaluate().value;
  }
  replace({
    path: children[0].parentPath,
    string,
    filename
  });
}